@@ -3,7 +3,7 @@ use 5.004;
 use strict;
 use vars qw($VERSION @ISA @EXPORT $CWD @CWD);
 # ABSTRACT: a more sensible way to change directories
-our $VERSION = '0.1005'; # VERSION
+our $VERSION = '0.1006'; # VERSION
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -18,7 +18,7 @@ tie @CWD, 'File::chdir::ARRAY'  or die "Can't tie \@CWD";
 
 sub _abs_path { 
     # Otherwise we'll never work under taint mode.
-    my($cwd) = Cwd::abs_path =~ /(.*)/;
+    my($cwd) = Cwd::abs_path =~ /(.*)/s;
     # Run through File::Spec, since everything else uses it 
     return canonpath($cwd);
 }
@@ -200,7 +200,7 @@ File::chdir - a more sensible way to change directories
 
 =head1 VERSION
 
-version 0.1005
+version 0.1006
 
 =head1 SYNOPSIS
 
